@@ -219,7 +219,10 @@ namespace KeePass.Forms
 
 		protected override bool ProcessDialogKey(Keys keyData)
 		{
-			if(((keyData == Keys.Return) || (keyData == Keys.Enter)) && m_tbFilter.Focused)
+			Keys k = (keyData & Keys.KeyCode);
+
+			if((k == Keys.Return) && ((keyData & (Keys.Control | Keys.Alt)) ==
+				Keys.None) && m_tbFilter.Focused) // Return == Enter
 				return false; // Forward to TextBox
 
 			return base.ProcessDialogKey(keyData);
@@ -227,9 +230,9 @@ namespace KeePass.Forms
 
 		private void OnFilterKeyDown(object sender, KeyEventArgs e)
 		{
-			if((e.KeyCode == Keys.Return) || (e.KeyCode == Keys.Enter))
+			if(e.KeyCode == Keys.Return) // Return == Enter
 			{
-				e.SuppressKeyPress = true;
+				UIUtil.SetHandled(e, true);
 
 				SearchParameters sp = new SearchParameters();
 				sp.SearchString = m_tbFilter.Text;
@@ -244,8 +247,8 @@ namespace KeePass.Forms
 
 		private void OnFilterKeyUp(object sender, KeyEventArgs e)
 		{
-			if((e.KeyCode == Keys.Return) || (e.KeyCode == Keys.Enter))
-				e.SuppressKeyPress = true;
+			if(e.KeyCode == Keys.Return) // Return == Enter
+				UIUtil.SetHandled(e, true);
 		}
 	}
 }
