@@ -31,6 +31,7 @@ using KeePass.Util;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
+using KeePassLib.Utility;
 
 namespace KeePass.Forms
 {
@@ -69,7 +70,7 @@ namespace KeePass.Forms
 			if(dlg == null) { Debug.Assert(false); return; }
 
 			dlg.EndLogging();
-			dlg.Close();
+			dlg.CloseEx();
 			UIUtil.DestroyForm(dlg);
 		}
 
@@ -186,6 +187,14 @@ namespace KeePass.Forms
 			return !m_bCancelled;
 		}
 
+		internal void CloseEx()
+		{
+			Close();
+
+			if(MonoWorkarounds.IsRequired(1710))
+				OnFormClosed(this, new FormClosedEventArgs(CloseReason.UserClosing));
+		}
+
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
 		{
 			GlobalWindowManager.RemoveWindow(this);
